import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { createRef } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { highlightText } from '@s-ui/js/lib/string';
import AtomCheckbox from '@s-ui/react-atom-checkbox';
import handlersFactory from './handlersFactory';
var BASE_CLASS = 'sui-MoleculeDropdownOption';
var CLASS_CHECKBOX = BASE_CLASS + "-checkbox";
var MODIFIER_TWO_LINES = "twoLines";
var MODIFIER_THREE_LINES = "threeLines";
var MODIFIER_NO_WRAP = 'noWrap';
var MODIFIER_LINE_WRAP = 'lineWrap';
var CLASS_TEXT = BASE_CLASS + "-text";
var CLASS_DISABLED = BASE_CLASS + "--disabled";
var CLASS_HIGHLIGHTED = "is-highlighted";
var CLASS_HIGHLIGHTED_MARK = BASE_CLASS + "-mark";
var TEXT_WRAP_STYLES = {
  NO_WRAP: 'noWrap',
  TWO_LINES: 'twoLines',
  THREE_LINES: 'threeLines',
  LINE_WRAP: 'lineWrap'
};

var MoleculeDropdownOption = function MoleculeDropdownOption(_ref) {
  var _cx;

  var children = _ref.children,
      selected = _ref.selected,
      checkbox = _ref.checkbox,
      disabled = _ref.disabled,
      highlightQuery = _ref.highlightQuery,
      onSelectKey = _ref.onSelectKey,
      onSelect = _ref.onSelect,
      innerRef = _ref.innerRef,
      value = _ref.value,
      withTwoLinesText = _ref.withTwoLinesText,
      textWrap = _ref.textWrap;
  var className = cx(BASE_CLASS, (_cx = {}, _cx[CLASS_CHECKBOX] = checkbox, _cx[CLASS_DISABLED] = disabled, _cx['is-selected'] = selected, _cx));
  var innerClassName = cx([CLASS_TEXT, (withTwoLinesText || textWrap === TEXT_WRAP_STYLES.TWO_LINES) && CLASS_TEXT + "--" + MODIFIER_TWO_LINES, textWrap === TEXT_WRAP_STYLES.THREE_LINES && CLASS_TEXT + "--" + MODIFIER_THREE_LINES, textWrap === TEXT_WRAP_STYLES.LINE_WRAP && CLASS_TEXT + "--" + MODIFIER_LINE_WRAP, (!withTwoLinesText && !textWrap || textWrap === TEXT_WRAP_STYLES.NO_WRAP) && CLASS_TEXT + "--" + MODIFIER_NO_WRAP]);

  var _handlersFactory = handlersFactory({
    disabled: disabled,
    value: value,
    onSelectKey: onSelectKey,
    onSelect: onSelect
  }),
      handleClick = _handlersFactory.handleClick,
      handleKeyDown = _handlersFactory.handleKeyDown,
      handleFocus = _handlersFactory.handleFocus;

  var renderHighlightOption = function renderHighlightOption(option) {
    if (typeof option !== 'string') {
      return /*#__PURE__*/_jsx("span", {
        onFocus: handleInnerFocus,
        className: innerClassName,
        children: option
      });
    }

    var mark = highlightText({
      value: option,
      query: highlightQuery,
      startTag: "<mark class=\"" + cx(CLASS_HIGHLIGHTED_MARK, CLASS_HIGHLIGHTED) + "\">",
      endTag: '</mark>'
    });
    return /*#__PURE__*/_jsx("span", {
      onFocus: handleInnerFocus,
      dangerouslySetInnerHTML: {
        __html: mark
      },
      className: innerClassName
    });
  };

  var handleInnerFocus = function handleInnerFocus(ev) {
    ev.preventDefault();
    innerRef.current.focus();
  };

  return /*#__PURE__*/_jsxs("li", {
    ref: innerRef,
    tabIndex: "0",
    className: className,
    onClick: handleClick,
    onKeyDown: handleKeyDown,
    onFocus: handleFocus,
    children: [checkbox && /*#__PURE__*/_jsx(AtomCheckbox, {
      checked: selected,
      disabled: disabled,
      onFocus: handleInnerFocus
    }), highlightQuery ? renderHighlightOption(children) : /*#__PURE__*/_jsx("span", {
      onFocus: handleInnerFocus,
      className: innerClassName,
      children: children
    })]
  });
};

MoleculeDropdownOption.displayName = 'MoleculeDropdownOption';
MoleculeDropdownOption.propTypes = process.env.NODE_ENV !== "production" ? {
  /** option value */
  value: PropTypes.string.isRequired,

  /** Content to be included in the option */
  children: PropTypes.node,

  /** Contains checkbox */
  checkbox: PropTypes.bool,

  /** Is disabled */
  disabled: PropTypes.bool,

  /** onSelect callback (ev, {value}) */
  onSelect: PropTypes.func,

  /** Is initial selected */
  selected: PropTypes.bool,

  /** Text to be highlighted in the option text if found */
  highlightQuery: PropTypes.string,

  /* key to provoke the onClick callback. Valid any value defined here → https://www.w3.org/TR/uievents-key/#named-key-attribute-values */
  onSelectKey: PropTypes.oneOfType([PropTypes.string, PropTypes.array]),

  /** Custom ref handler that will be assigned to the "target" element */
  innerRef: PropTypes.object,

  /** Text with css clamp = 2 */
  withTwoLinesText: PropTypes.bool,

  /** Text wrapping options */
  textWrap: PropTypes.oneOf(Object.values(TEXT_WRAP_STYLES))
} : {};
MoleculeDropdownOption.defaultProps = {
  checkbox: false,
  disabled: false,
  onSelect: function onSelect() {},
  selected: false,
  onSelectKey: 'Enter',
  innerRef: /*#__PURE__*/createRef()
};
export default MoleculeDropdownOption;
export { handlersFactory };
export { TEXT_WRAP_STYLES as MoleculeDropdownOptionTextWrapStyles };